==> panda_server-0.2.0.tar.gz: panda_server-0.2.0/INSTALL.md <==
Installation
--------------------

1. Install httpd, httpd-devel, mod_ssl, gridsite

1. Install panda-common and panda-server.
   1. via tarball
   ```
   git clone git://github.com/PanDAWMS/panda-common.git
   git clone git://github.com/PanDAWMS/panda-server.git
   python setup.py install
   cd ../panda-server
   python setup.py install
   ```
   1. via pip
   ```
   pip install panda-server
   ``` 
   
1. Install database modules: cx_Oracle for Oracle or MySQLdb for MySQL/MariaDB
1. Modify config files.

   ```
   cd INSTALLDIR/etc/panda
   mv panda_common.cfg.rpmnew panda_common.cfg
   mv panda_server.cfg.rpmnew panda_server.cfg       
   mv panda_server-httpd-FastCGI.conf.rpmnew panda_server-httpd.conf        
   vi panda_server.cfg panda_server-httpd.conf
   ln -fs INSTALLDIR/etc/panda/panda_server.sysconfig /etc/sysconfig/panda_server
   vi /etc/sysconfig/panda_server
   ```

1. Make log and cache dirs, and change owner if needed. 
   ```
   mkdir -p /var/log/panda
   mkdir -p /var/log/panda/wsgisocks
   mkdir -p /var/cache/pandaserver
   chown atlpan:zp /var/log/panda
   chown atlpan:zp /var/log/panda/wsgisocks
   chown atlpan:zp /var/cache/pandaserver
   # If log rotation is needed
   ln -fs /etc/panda/panda_server.logrotate /etc/logrotate.d/panda_server
   ```

Start the server
--------------------

1. Install service
   ```
   ln -fs INSTALLDIR/etc/init.d/panda_server /etc/rc.d/init.d/httpd-pandasrv
   /sbin/chkconfig --add httpd-pandasrv
   /sbin/chkconfig httpd-pandasrv on
   ```

1. Add the following to crontab.
   ```
   0-59/5 * * * * INSTALLDIR/usr/bin/panda_server-add.sh > /dev/null 2>&1
   15 0-21/3 * * * INSTALLDIR/usr/bin/panda_server-copyArchive.sh > /dev/null 2>&1
   ```
   
1. Run the server.
   ```
   /sbin/service httpd-pandasrv start
   ```

1. Stop the server.
   ```
   /sbin/service httpd-pandasrv stop
   ```


Uploading to pip
--------------------
```
python setup.py sdist upload
```
Note that source should be uploaded so that wheel locally generates setup files correctly.

==> panda_server-0.3.21.tar.gz: panda_server-0.3.21/INSTALL.md <==
Installation
--------------------

1. Install httpd, httpd-devel, mod_ssl, gridsite

1. Install panda-common and panda-server.
   1. via tarball
   ```
   git clone git://github.com/PanDAWMS/panda-common.git
   git clone git://github.com/PanDAWMS/panda-server.git
   python setup.py install
   cd ../panda-server
   python setup.py install
   ```
   1. via pip
   ```
   pip install panda-server
   ``` 
   
1. Install database modules: oracledb for Oracle or MySQLdb for MySQL/MariaDB
1. Modify config files.

   ```
   cd INSTALLDIR/etc/panda
   mv panda_common.cfg.rpmnew panda_common.cfg
   mv panda_server.cfg.rpmnew panda_server.cfg       
   mv panda_server-httpd-FastCGI.conf.rpmnew panda_server-httpd.conf        
   vi panda_server.cfg panda_server-httpd.conf
   ln -fs INSTALLDIR/etc/panda/panda_server.sysconfig /etc/sysconfig/panda_server
   vi /etc/sysconfig/panda_server
   ```

1. Make log and cache dirs, and change owner if needed. 
   ```
   mkdir -p /var/log/panda
   mkdir -p /var/log/panda/wsgisocks
   mkdir -p /var/cache/pandaserver
   chown atlpan:zp /var/log/panda
   chown atlpan:zp /var/log/panda/wsgisocks
   chown atlpan:zp /var/cache/pandaserver
   # If log rotation is needed
   ln -fs /etc/panda/panda_server.logrotate /etc/logrotate.d/panda_server
   ```

Start the server
--------------------

1. Install service
   ```
   ln -fs INSTALLDIR/etc/init.d/panda_server /etc/rc.d/init.d/httpd-pandasrv
   /sbin/chkconfig --add httpd-pandasrv
   /sbin/chkconfig httpd-pandasrv on
   ```

1. Add the following to crontab.
   ```
   0-59/5 * * * * INSTALLDIR/usr/bin/panda_server-add.sh > /dev/null 2>&1
   15 0-21/3 * * * INSTALLDIR/usr/bin/panda_server-copyArchive.sh > /dev/null 2>&1
   ```
   
1. Run the server.
   ```
   /sbin/service httpd-pandasrv start
   ```

1. Stop the server.
   ```
   /sbin/service httpd-pandasrv stop
   ```


Uploading to pip
--------------------
```
python setup.py sdist upload
```
Note that source should be uploaded so that wheel locally generates setup files correctly.
